@@ -67,6 +67,12 @@ VALID_COLOR_LENGTHS = (3, 6)
 meaning that only colors of these size are allowed
 by the stylesheet analyser """
 
+AT_RULES_REGEX_VALUE = r"\@charset|\@import .*;"
+""" The at rules regex value """
+
+AT_RULES_REGEX = re.compile(AT_RULES_REGEX_VALUE)
+""" The at rules regex """
+
 URL_REGEX_VALUE = r"url\([\"'](.*)[\"']\)"
 """ The url regex value """
 
@@ -303,6 +309,13 @@ def process_property_line(property_line, line_number, indentation):
         extra.warn("Empty stylesheet property at line %s" % line_number)
         return property_line
 
+    # in case no separator is present between the name of the property
+    # the value of it a warning is raised and the value returned immediately
+    # to avoid further (unavoidable) errors
+    if not ":" in property_line:
+        extra.warn("No value set for property at line %s" % line_number)
+        return property_line
+
     # strips the line to the right so that no newline characters
     # exist (much simpler to manage lines without newlines)
     property_line = property_line.rstrip()
@@ -580,6 +593,10 @@ def cleanup_properties(
         elif comments_started:
             # does nothing, will just write the line as is
             pass
+        # in case the line contains an at rule specification
+        elif AT_RULES_REGEX.match(line):
+            # after an at rule, a newline must follow
+            needs_newline = True
         # in case the line contains a full rule specification
         # does nothing, will just write line as is as there's
         # very few thing possible to optimize under this situation
