@@ -90,6 +90,11 @@ class StylesheetsTest(unittest.TestCase):
 max-width: 1170px;;;
   border   : 0;
         }
+
+            master {
+  padding   : 0;
+   -webkit-border-radius: 3px;;;
+        }
 }
 """
         expected = """@media (max-width: 539px) and (min-width: 375px) {
@@ -97,6 +102,11 @@ max-width: 1170px;;;
         border: none;
         max-width: 1170px;
     }
+
+    master {
+        -webkit-border-radius: 3px 3px 3px 3px;
+        padding: 0px 0px 0px 0px;
+    }
 }
 """
         buffer = legacy.BytesIO(input)
@@ -105,9 +115,24 @@ max-width: 1170px;;;
             windows_newline = False,
             property_order = (
                 "border",
-                "max-width"
+                "-webkit-border-radius",
+                "max-width",
+                "padding"
             )
         )
         result.seek(0)
         result = result.read()
         self.assertEqual(result, expected)
+
+    def test_at_rules(self):
+        input = b"""@charset "utf-8";"""
+        expected = """@charset "utf-8";
+"""
+        buffer = legacy.BytesIO(input)
+        result = stylesheets.cleanup_properties(
+            buffer,
+            windows_newline = False
+        )
+        result.seek(0)
+        result = result.read()
+        self.assertEqual(result, expected)
